@@ -22,13 +22,11 @@ class Batch:
 def batch_records(
     records: List[TimestreamRecord],
     max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-    min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-    logger: logging.Logger = DEFAULT_LOGGER
+    min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
 ) -> List[Batch]:
     batches, remaining = [], records
-    logger.info(f"MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
+    DEFAULT_LOGGER.info(f"MAX BATCH || {max_batch_size}  MIN COMMON DIM || {min_common_dimensions}")
     while len(remaining) > 0:
-        logger.info(len(remaining))
         batch, remaining = _batch_records_helper(
             remaining, max_batch_size, min_common_dimensions
         )
@@ -49,7 +47,9 @@ def _batch_records_helper(
     
     indexes = [0] # indexes for all the records in the batch
     common_dimensions = records[0].dimensions
+    DEFAULT_LOGGER.info(f"COMMON DIMENSIONS{common_dimensions}")
     min_common_dimensions = min(min_common_dimensions, len(common_dimensions))
+    DEFAULT_LOGGER.info(f"MIN COMMON DIMENSION {min_common_dimensions}")
 
     for i in range(1, len(records)):
         if len(indexes) >= max_batch_size:
@@ -59,9 +59,10 @@ def _batch_records_helper(
         for k in common_dimensions.get_dimension_keys():
             if dimensions.get_dimension(k) == common_dimensions.get_dimension(k):
                 shared[k] = True
-        
+        DEFAULT_LOGGER.info(f"SHARED {shared}")
         # Add the record to the batch if it has the minimum number of shared dimensions
         if len(shared) >= min_common_dimensions:
+            DEFAULT_LOGGER.info(f"SHARED >= MCD {len(shared)}")
             keys_to_remove = [k for k in common_dimensions.get_dimension_keys() if k not in shared]
             for k in keys_to_remove:
                 common_dimensions.remove_dimension(k)
